==> zio-aws-ec2_2.12-7.21.15.12-sources.jar: zio/aws/ec2/model/EnableTransitGatewayRouteTablePropagationRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.{
  TransitGatewayRouteTableAnnouncementId,
  TransitGatewayAttachmentId,
  TransitGatewayRouteTableId
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class EnableTransitGatewayRouteTablePropagationRequest(
    transitGatewayRouteTableId: TransitGatewayRouteTableId,
    transitGatewayAttachmentId: Optional[TransitGatewayAttachmentId] =
      Optional.Absent,
    dryRun: Optional[Boolean] = Optional.Absent,
    transitGatewayRouteTableAnnouncementId: Optional[
      TransitGatewayRouteTableAnnouncementId
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.EnableTransitGatewayRouteTablePropagationRequest = {
    import EnableTransitGatewayRouteTablePropagationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.EnableTransitGatewayRouteTablePropagationRequest
      .builder()
      .transitGatewayRouteTableId(
        TransitGatewayRouteTableId.unwrap(
          transitGatewayRouteTableId
        ): java.lang.String
      )
      .optionallyWith(
        transitGatewayAttachmentId.map(value =>
          TransitGatewayAttachmentId.unwrap(value): java.lang.String
        )
      )(_.transitGatewayAttachmentId)
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .optionallyWith(
        transitGatewayRouteTableAnnouncementId.map(value =>
          TransitGatewayRouteTableAnnouncementId.unwrap(value): java.lang.String
        )
      )(_.transitGatewayRouteTableAnnouncementId)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.EnableTransitGatewayRouteTablePropagationRequest.ReadOnly =
    zio.aws.ec2.model.EnableTransitGatewayRouteTablePropagationRequest
      .wrap(buildAwsValue())
}
object EnableTransitGatewayRouteTablePropagationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.EnableTransitGatewayRouteTablePropagationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.EnableTransitGatewayRouteTablePropagationRequest =
      zio.aws.ec2.model.EnableTransitGatewayRouteTablePropagationRequest(
        transitGatewayRouteTableId,
        transitGatewayAttachmentId.map(value => value),
        dryRun.map(value => value),
        transitGatewayRouteTableAnnouncementId.map(value => value)
      )
    def transitGatewayRouteTableId: TransitGatewayRouteTableId
    def transitGatewayAttachmentId: Optional[TransitGatewayAttachmentId]
    def dryRun: Optional[Boolean]
    def transitGatewayRouteTableAnnouncementId
        : Optional[TransitGatewayRouteTableAnnouncementId]
    def getTransitGatewayRouteTableId
        : ZIO[Any, Nothing, TransitGatewayRouteTableId] =
      ZIO.succeed(transitGatewayRouteTableId)
    def getTransitGatewayAttachmentId
        : ZIO[Any, AwsError, TransitGatewayAttachmentId] =
      AwsError.unwrapOptionField(
        "transitGatewayAttachmentId",
        transitGatewayAttachmentId
      )
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
    def getTransitGatewayRouteTableAnnouncementId
        : ZIO[Any, AwsError, TransitGatewayRouteTableAnnouncementId] =
      AwsError.unwrapOptionField(
        "transitGatewayRouteTableAnnouncementId",
        transitGatewayRouteTableAnnouncementId
      )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.EnableTransitGatewayRouteTablePropagationRequest
  ) extends zio.aws.ec2.model.EnableTransitGatewayRouteTablePropagationRequest.ReadOnly {
    override val transitGatewayRouteTableId: TransitGatewayRouteTableId =
      zio.aws.ec2.model.primitives
        .TransitGatewayRouteTableId(impl.transitGatewayRouteTableId())
    override val transitGatewayAttachmentId
        : Optional[TransitGatewayAttachmentId] = zio.aws.core.internal
      .optionalFromNullable(impl.transitGatewayAttachmentId())
      .map(value =>
        zio.aws.ec2.model.primitives.TransitGatewayAttachmentId(value)
      )
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
    override val transitGatewayRouteTableAnnouncementId
        : Optional[TransitGatewayRouteTableAnnouncementId] =
      zio.aws.core.internal
        .optionalFromNullable(impl.transitGatewayRouteTableAnnouncementId())
        .map(value =>
          zio.aws.ec2.model.primitives
            .TransitGatewayRouteTableAnnouncementId(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.EnableTransitGatewayRouteTablePropagationRequest
  ): zio.aws.ec2.model.EnableTransitGatewayRouteTablePropagationRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.102.8-sources.jar: zio/aws/ec2/model/EnableTransitGatewayRouteTablePropagationRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.{
  TransitGatewayAttachmentId,
  TransitGatewayRouteTableId
}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class EnableTransitGatewayRouteTablePropagationRequest(
    transitGatewayRouteTableId: TransitGatewayRouteTableId,
    transitGatewayAttachmentId: TransitGatewayAttachmentId
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.EnableTransitGatewayRouteTablePropagationRequest = {
    import EnableTransitGatewayRouteTablePropagationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.EnableTransitGatewayRouteTablePropagationRequest
      .builder()
      .transitGatewayRouteTableId(
        TransitGatewayRouteTableId.unwrap(
          transitGatewayRouteTableId
        ): java.lang.String
      )
      .transitGatewayAttachmentId(
        TransitGatewayAttachmentId.unwrap(
          transitGatewayAttachmentId
        ): java.lang.String
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.EnableTransitGatewayRouteTablePropagationRequest.ReadOnly =
    zio.aws.ec2.model.EnableTransitGatewayRouteTablePropagationRequest
      .wrap(buildAwsValue())
}
object EnableTransitGatewayRouteTablePropagationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.EnableTransitGatewayRouteTablePropagationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.EnableTransitGatewayRouteTablePropagationRequest =
      zio.aws.ec2.model.EnableTransitGatewayRouteTablePropagationRequest(
        transitGatewayRouteTableId,
        transitGatewayAttachmentId
      )
    def transitGatewayRouteTableId: TransitGatewayRouteTableId
    def transitGatewayAttachmentId: TransitGatewayAttachmentId
    def getTransitGatewayRouteTableId
        : ZIO[Any, Nothing, TransitGatewayRouteTableId] =
      ZIO.succeed(transitGatewayRouteTableId)
    def getTransitGatewayAttachmentId
        : ZIO[Any, Nothing, TransitGatewayAttachmentId] =
      ZIO.succeed(transitGatewayAttachmentId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.EnableTransitGatewayRouteTablePropagationRequest
  ) extends zio.aws.ec2.model.EnableTransitGatewayRouteTablePropagationRequest.ReadOnly {
    override val transitGatewayRouteTableId: TransitGatewayRouteTableId =
      zio.aws.ec2.model.primitives
        .TransitGatewayRouteTableId(impl.transitGatewayRouteTableId())
    override val transitGatewayAttachmentId: TransitGatewayAttachmentId =
      zio.aws.ec2.model.primitives
        .TransitGatewayAttachmentId(impl.transitGatewayAttachmentId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.EnableTransitGatewayRouteTablePropagationRequest
  ): zio.aws.ec2.model.EnableTransitGatewayRouteTablePropagationRequest.ReadOnly =
    new Wrapper(impl)
}
